---
title: 페이팔 상세 계약절차
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 페이팔 상세 계약절차
  description: >-
    페이팔의 전자결제 계약절차는 가입신청서 제출 - 페이팔 홈페이지를 통한 추가 온보딩과정 진행 - 포트원 관리자콘솔 채널설정 - 개발진행
    및 서비스 오픈으로 이뤄집니다. 각 계약절차를 확인해보세요.
  keywords:
    - 페이팔
    - 결제대행사 계약
tags:
  - 페이팔
  - 결제대행사 계약
pgCompanies:
  - 페이팔
searchTags:
  - 페이팔계약문의
  - 페이팔계약방법
  - 페이팔가입방법
  - 페이팔가입
  - 페이팔등록
  - 페이팔가입절차
  - 페이팔사용
  - 페이팔계약
  - 페이팔이용방법
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="페이팔의 경우 별도 계약절차가 없어 하기 절차를 진행하신 뒤 즉시 운영 서비스 사용이 가능합니다." />

### **가입신청서 제출**

[포트원 관리자콘솔↗](https://admin.portone.io/) 안에서 페이팔의 가입신청서를 제출합니다.\
(접수시 페이팔(SPB/RT) 서비스를 기준으로 적용되어 제출됩니다)

- 경로 : [포트원 관리자콘솔↗](https://admin.portone.io/) 회원가입 및 로그인 > 좌측 상단 \[전자결제 신청] 버튼 클릭 > 사업자등록증 업로드 > 페이팔 선택 후 제출

<Callout icon="" title="전자결제 신청방법 보러가기↗" />





### **페이팔 홈페이지를 통한 추가 온보딩 과정 진행**

가입신청사 제출까지 진행하시면 담당자님 메일로 메일이 발송됩니다. 메일 내 \[<Highlight text="페이팔 가입하러가기" />] 버튼을 클릭하여 온보딩 과정을 완료합니다. (이미 페이팔 비즈니스 계정이 있는 경우 링크 내에서 바로 로그인합니다.)

#### **포트원 온보딩 절차**<Highlight text="(필수)" />

[포트원 관리자콘솔↗](https://admin.portone.io/) 전자결제 신청 > 담당자님 메일로 수신받으신 메일 내 링크로 접속하여 로그인 및 회원가입하여 아래와 같이 PortOne와 연동되도록 합니다.

<Callout title="포트원 전자결제 신청방식 보러가기 ↗" content="일반결제와 정기결제를 모두 이용하신다면, 각각 선택하여 접수해주시기 바랍니다." icon="" />



### **포트원 관리자콘솔 채널설정**

- 포트원 관리자 콘솔 테스트채널 혹은 실 운영 채널을 선택하여 설정해주세요.
- 페이팔(SPB/RT) 테스트환경의 경우 당사에서 제공드리는 KEY를 사용하시면 되며, 실 운영환경의 경우 운영하시는 고객사 페이팔 계정의 key를 설정해주셔야 합니다.

<Callout title="페이팔 채널설정방법 보러가기 ↗" />

### **개발진행 및 서비스 오픈**

포트원의 [개발 연동 가이드↗](https://developers.portone.io/opi/ko/integration/pg/v1/spb/readme?v=v1)를 참고하셔서 사이트 내 개발을 진행하시고 개발연동이 완료된 경우 서비스를 오픈하실 수 있습니다.
